netapp_ontap.resources.snmp API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.snmp`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

Cluster wide SNMP configuration. You can configure or retrieve the following SNMP parameters using this endpoint:

- enable or disable SNMP
- enable or disable SNMP authentication traps
- enable or disable SNMP traps

##

This endpoint can also be used to trigger an SNMP test trap.

## Examples

### Disables SNMP protocol in the cluster.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Snmp

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Snmp()
        resource.enabled = False
        resource.patch()

### Enables SNMP authentication traps in the cluster.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Snmp

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Snmp()
        resource.auth_traps_enabled = True
        resource.patch()

### Enables SNMP protocol and SNMP authentication traps in the cluster.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Snmp

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Snmp()
        resource.enabled = True
        resource.auth_traps_enabled = True
        resource.patch()

### Disables the SNMP trap subsystem in the cluster. Once the SNMP trap subsystem is disabled, the cluster stops sending SNMP traps.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Snmp

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Snmp()
        resource.traps_enabled = False
        resource.patch()

### Sets the contact and location for the SNMP server

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Snmp

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Snmp()
        resource.contact = "support@company.com"
        resource.location = "Building 1"
        resource.patch()

### Triggers an SNMP test trap.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Snmp

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Snmp()
        resource.trigger_test_trap = True
        resource.patch()

### Enables the SNMP protocol in the cluster, SNMP traps, and triggers an SNMP test trap.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Snmp

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Snmp()
        resource.enabled = True
        resource.traps_enabled = True
        resource.trigger_test_trap = True
        resource.patch()

## Classes

`class Snmp (*args, **kwargs)`

  Cluster-wide SNMP configuration.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Methods

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves the cluster wide SNMP configuration.

    ### Related ONTAP commands

    - `options snmp.enable`
    - `system snmp show`

    ### Learn more

    - `DOC /support/snmp`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  `def patch (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Updates the cluster wide SNMP configuration, such as: * enabling or disabling SNMP * enabling or disabling SNMP traps * enabling or disabling authentication traps * setting the contact and location information for the SNMP server * triggering an SNMP test trap

    ### Related ONTAP commands

    - `options snmp.enable`
    - `system snmp authtrap`
    - `system snmp init`

    ### Learn more

    - `DOC /support/snmp`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class SnmpSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the Snmp object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `auth_traps_enabled: bool GET PATCH`

    Specifies whether to enable or disable SNMP authentication traps.

    Example: true

  `contact: str GET PATCH`

    Specifies the contact person for the SNMP server

    Example: support@company.com

  `enabled: bool GET PATCH`

    Specifies whether to enable or disable SNMP.

    Example: true

  `links: SelfLink GET`

    The links field of the snmp.

  `location: str GET PATCH`

    Specifies the location of the SNMP server

    Example: Building 1

  `traps_enabled: bool GET PATCH`

    Specifies whether to enable or disable SNMP traps.

    Example: true

  `trigger_test_trap: bool PATCH`

    Trigger a test SNMP trap.

    Example: true